@@ -1,6 +1,7 @@
 import asyncio
 import aiohttp
 import traceback
+import sys
 
 from .handlers import Handlers
 from .dispatcher import Dispatcher
@@ -16,10 +17,14 @@ class Bot:
         self.group_id = group_id
         self.config = {}
         self.handlers = []
+        self.middlewares = []
 
     def handle(self, handler: Handler) -> None:
         self.handlers.append(handler)
 
+    def add_middleware(self, middleware) -> None:
+        self.middlewares.append(middleware)
+
     async def run_polling(self) -> None:
         async with aiohttp.ClientSession() as session:
             async with session.get("https://api.vk.com/method/groups.getLongPollServer",
@@ -44,11 +49,23 @@ class Bot:
 
                             self.config["ts"] = event["ts"]
 
-                            tasks = [asyncio.create_task(handler.new_event(self.token, updates[0]))
-                                     for handler in self.handlers if handler.event_type == updates[0]["type"]]
+                            asyncio.create_task(self.send_event(updates[0]))
 
                     except:
-                        print(traceback.format_exc())
+                        sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
+
+    async def send_event(self, updates):
+        tasks = [asyncio.create_task(middleware.pre(updates))
+                 for middleware in self.middlewares if middleware.event_type in (updates["type"], None)]
+        await asyncio.gather(*tasks)
+
+        tasks = [asyncio.create_task(handler.new_event(self.token, updates))
+                 for handler in self.handlers if handler.event_type == updates["type"]]
+        await asyncio.gather(*tasks)
+
+        tasks = [asyncio.create_task(middleware.post(updates))
+                 for middleware in self.middlewares if middleware.event_type in (updates["type"], None)]
+        await asyncio.gather(*tasks)
 
     async def execute(self, method: str, **params) -> dict:
         query = f"https://api.vk.com/method/{method}?"
@@ -63,4 +80,4 @@ class Bot:
 
 def run_polling(bot: Bot) -> None:
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(bot.run_polling())
\ No newline at end of file
+    loop.run_until_complete(bot.run_polling())
