@@ -1,4 +1,6 @@
 from typing import Union
+import traceback
+import sys
 
 import asyncio
 import aiohttp
@@ -43,7 +45,10 @@ class CustomHandler(Handler):
             post_id = event["object"].get("post_id")
             owner_id = event["object"].get("owner_id")
 
-        await self.func(event, token, text, user_id, peer_id=peer_id, owner_id=owner_id, post_id=post_id)
+        try:
+            await self.func(event, token, text, user_id, peer_id=peer_id, owner_id=owner_id, post_id=post_id)
+        except:
+            sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
 
 class MessageNewHandler(Handler):
@@ -54,12 +59,14 @@ class MessageNewHandler(Handler):
             text = event["object"]["message"]["text"] if not self.is_lower else event["object"]["message"]["text"].lower()
             peer_id = event["object"]["message"]["peer_id"]
             user_id = event["object"]["message"]["from_id"]
+        except KeyError:
+            return
 
-            if self.condition.new_event(text=text, user_id=user_id, peer_id=peer_id):
+        if self.condition.new_event(text=text, user_id=user_id, peer_id=peer_id):
+            try:
                 await self.func(event, token, text, user_id, peer_id=peer_id)
-
-        except (IndexError, KeyError):
-            pass
+            except:
+                sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
 
 class MessageEditHandler(Handler):
@@ -70,12 +77,14 @@ class MessageEditHandler(Handler):
             text = event["object"]["text"] if not self.is_lower else event["object"]["text"].lower()
             peer_id = event["object"]["peer_id"]
             user_id = event["object"]["from_id"]
+        except KeyError:
+            return
 
-            if self.condition.new_event(text=text, user_id=user_id, peer_id=peer_id):
+        if self.condition.new_event(text=text, user_id=user_id, peer_id=peer_id):
+            try:
                 await self.func(event, token, text, user_id, peer_id=peer_id)
-
-        except (IndexError, KeyError):
-            pass
+            except:
+                sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
 
 class WallReplyNewHandler(Handler):
@@ -87,12 +96,14 @@ class WallReplyNewHandler(Handler):
             owner_id = event["object"]["owner_id"]
             user_id = event["object"]["from_id"]
             post_id = event["object"]["post_id"]
+        except KeyError:
+            return
 
-            if self.condition.new_event(text=text, user_id=user_id, post_id=post_id, owner_id=owner_id):
+        if self.condition.new_event(text=text, user_id=user_id, post_id=post_id, owner_id=owner_id):
+            try:
                 await self.func(event, token, text, user_id, owner_id=owner_id, post_id=post_id)
-
-        except (IndexError, KeyError):
-            pass
+            except:
+                sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
 
 class WallReplyEditHandler(WallReplyNewHandler):
@@ -108,12 +119,14 @@ class WallPostNewHandler(Handler):
             owner_id = event["object"]["owner_id"]
             user_id = event["object"]["from_id"]
             post_id = event["object"]["id"]
+        except KeyError:
+            return
 
-            if self.condition.new_event(text=text, user_id=user_id, post_id=post_id, owner_id=owner_id):
+        if self.condition.new_event(text=text, user_id=user_id, post_id=post_id, owner_id=owner_id):
+            try:
                 await self.func(event, token, text, user_id, owner_id=owner_id, post_id=post_id)
-
-        except (IndexError, KeyError):
-            pass
+            except:
+                sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
 
 class BoardPostNewHandler(Handler):
@@ -125,12 +138,14 @@ class BoardPostNewHandler(Handler):
             owner_id = event["group_id"]
             user_id = event["object"]["from_id"]
             post_id = event["object"]["topic_id"]
+        except KeyError:
+            return
 
-            if self.condition.new_event(text=text, user_id=user_id, post_id=post_id, owner_id=owner_id):
+        if self.condition.new_event(text=text, user_id=user_id, post_id=post_id, owner_id=owner_id):
+            try:
                 await self.func(event, token, text, user_id, owner_id=owner_id, post_id=post_id)
-
-        except (IndexError, KeyError):
-            pass
+            except:
+                sys.stderr.write(f"\n\n{traceback.format_exc()}\n\n")
 
 
 class BoardPostEditHandler(BoardPostNewHandler):
